diff --git a/mod/data/edit.php b/mod/data/edit.php
index e1bc855bc9c..a863de4aafd 100755
--- a/mod/data/edit.php
+++ b/mod/data/edit.php
@@ -24,6 +24,7 @@
require_once('../../config.php');
require_once('lib.php');
+ require_once("$CFG->libdir/rsslib.php");
$id = optional_param('id', 0, PARAM_INT); // course module id
$d = optional_param('d', 0, PARAM_INT); // database id
@@ -90,12 +91,26 @@
}
-/// Print the page header
+/// RSS and CSS and JS meta
+ $meta = '';
+ if (!empty($CFG->enablerssfeeds) && !empty($CFG->data_enablerssfeeds) && $data->rssarticles > 0) {
+ $rsspath = rss_get_url($course->id, $USER->id, 'data', $data->id);
+ $meta .= 'shortname.': %fullname%" href="'.$rsspath.'" />';
+ }
+ if ($data->csstemplate) {
+ $meta .= ' ';
+ }
+ if ($data->jstemplate) {
+ $meta .= '';
+ }
+
+/// Print the page header
$strdata = get_string('modulenameplural','data');
print_header_simple($data->name, '', "$strdata -> $data->name",
- '', '', true, update_module_button($cm->id, $course->id, get_string('modulename', 'data')),
+ '', $meta, true, update_module_button($cm->id, $course->id, get_string('modulename', 'data')),
navmenu($course, $cm), '', '');
print_heading(format_string($data->name));